aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorGlen Mazza <gmazza@apache.org>2004-07-25 01:00:35 +0000
committerGlen Mazza <gmazza@apache.org>2004-07-25 01:00:35 +0000
commit6c1dcb8a76af7fd9dd3654cd81ba9d2e5ea7374a (patch)
treeb87e0ebfda55aacba695b1bd9661610b37b841ab /src
parentcd49b6d553c7fd4c3bcd51e6d7c7a3a10a1898ea (diff)
downloadxmlgraphics-fop-6c1dcb8a76af7fd9dd3654cd81ba9d2e5ea7374a.tar.gz
xmlgraphics-fop-6c1dcb8a76af7fd9dd3654cd81ba9d2e5ea7374a.zip
reverted change in PropertySets; unnecessary.
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@197836 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src')
-rw-r--r--src/java/org/apache/fop/fo/PropertySets.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/java/org/apache/fop/fo/PropertySets.java b/src/java/org/apache/fop/fo/PropertySets.java
index d959e2997..8f4c12ef4 100644
--- a/src/java/org/apache/fop/fo/PropertySets.java
+++ b/src/java/org/apache/fop/fo/PropertySets.java
@@ -969,7 +969,7 @@ public class PropertySets {
// Merge the attributes from the child nodes into the parent.
for (boolean dirty = true; dirty; ) {
dirty = false;
for (int i = 1; i < elements.length; i++) {
@@ -1017,7 +1017,7 @@ public class PropertySets {
BitSet relevant = new BitSet();
BitSet valid = new BitSet();
int elementId;
- ArrayList childNodes;
+ ArrayList children;
Element(int elementId) {
this.elementId = elementId;
@@ -1043,14 +1043,14 @@ public class PropertySets {
* Add a single fo element as a content child.
*/
public void addContent(int elementId) {
- if (childNodes == null) {
- childNodes = new ArrayList();
+ if (children == null) {
+ children = new ArrayList();
}
- childNodes.add(elements[elementId]);
+ children.add(elements[elementId]);
}
/**
* Add a set of fo elements as content child nodes.
*/
public void addContent(BitSet elements) {
for (int i = 0; i < elements.size(); i++) {
@@ -1061,16 +1061,16 @@ public class PropertySets {
}
/**
* Merge the properties from the child nodes into the set of valid
* properties. Return true if at least one property could be added.
*/
public boolean merge() {
- if (childNodes == null) {
+ if (children == null) {
return false;
}
boolean dirty = false;
- for (int i = 0; i < childNodes.size(); i++) {
- Element child = (Element) childNodes.get(i);
+ for (int i = 0; i < children.size(); i++) {
+ Element child = (Element) children.get(i);
BitSet childValid = child.valid;
int n = childValid.length();
for (int j = 0; j < n; j++) {
@@ -969,7 +969,7 @@ public class PropertySets {
- // Merge the attributes from the child nodes into the parent.
+ // Merge the attributes from the children into the parent.
for (boolean dirty = true; dirty; ) {
dirty = false;
@@ -1043,14 +1043,14 @@ public class PropertySets {
}
/**
- * Add a set of fo elements as content child nodes.
+ * Add a set of fo elements as content children.
*/
public void addContent(BitSet elements) {
@@ -1061,16 +1061,16 @@ public class PropertySets {
}
/**
- * Merge the properties from the child nodes into the set of valid
+ * Merge the properties from the children into the set of valid
* properties. Return true if at least one property could be added.
*/